summaryrefslogtreecommitdiff
path: root/src/include/taler_merchant_testing_lib.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-04-27 16:32:59 +0200
committerChristian Grothoff <christian@grothoff.org>2020-04-27 16:32:59 +0200
commit5da121e9b0ec83f20a1a404f7049f9ff19aca32b (patch)
treea5a0701476655faf4fbf48c960ded20ef50b0dcc /src/include/taler_merchant_testing_lib.h
parente3d91bf74804871c5d7438a0b04265b69feba34a (diff)
downloadmerchant-5da121e9b0ec83f20a1a404f7049f9ff19aca32b.tar.gz
merchant-5da121e9b0ec83f20a1a404f7049f9ff19aca32b.tar.bz2
merchant-5da121e9b0ec83f20a1a404f7049f9ff19aca32b.zip
implement order claiming
Diffstat (limited to 'src/include/taler_merchant_testing_lib.h')
-rw-r--r--src/include/taler_merchant_testing_lib.h24
1 files changed, 12 insertions, 12 deletions
diff --git a/src/include/taler_merchant_testing_lib.h b/src/include/taler_merchant_testing_lib.h
index 33d23e50..4e0b3fd6 100644
--- a/src/include/taler_merchant_testing_lib.h
+++ b/src/include/taler_merchant_testing_lib.h
@@ -425,27 +425,27 @@ TALER_TESTING_cmd_merchant_post_orders (const char *label,
const char *order);
-/* ******************** OLD ******************* */
-
-
/**
- * Make a "proposal lookup" command.
+ * Make a "claim order" command.
*
* @param label command label.
* @param merchant_url base URL of the merchant backend
* serving the proposal lookup request.
* @param http_status expected HTTP response code.
* @param proposal_reference reference to a "proposal" CMD.
* @param order_id order id to lookup, can be NULL.
*
* @return the command.
*/
struct TALER_TESTING_Command
-TALER_TESTING_cmd_merchant_post_orders_lookup (const char *label,
- const char *merchant_url,
- unsigned int http_status,
- const char *proposal_reference,
- const char *order_id);
+TALER_TESTING_cmd_merchant_claim_order (const char *label,
+ const char *merchant_url,
+ unsigned int http_status,
+ const char *order_reference,
+ const char *order_id);
+
+
+/* ******************** OLD ******************* */
+
/**
* Make a "check payment" test command.
@@ -425,27 +425,27 @@ TALER_TESTING_cmd_merchant_post_orders (const char *label,
* serving the proposal lookup request.
* @param http_status expected HTTP response code.
- * @param proposal_reference reference to a "proposal" CMD.
- * @param order_id order id to lookup, can be NULL.
- *
+ * @param order_reference reference to a POST order CMD, can be NULL if @a order_id given
+ * @param order_id order id to lookup, can be NULL (then we use @a order_reference)
* @return the command.
*/